# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNatGatewaysResult',
    'AwaitableGetNatGatewaysResult',
    'get_nat_gateways',
    'get_nat_gateways_output',
]

@pulumi.output_type
class GetNatGatewaysResult:
    """
    A collection of values returned by getNatGateways.
    """
    def __init__(__self__, dry_run=None, enable_details=None, gateways=None, id=None, ids=None, name_regex=None, names=None, nat_gateway_name=None, nat_type=None, output_file=None, page_number=None, page_size=None, payment_type=None, resource_group_id=None, specification=None, status=None, tags=None, total_count=None, vpc_id=None):
        if dry_run and not isinstance(dry_run, bool):
            raise TypeError("Expected argument 'dry_run' to be a bool")
        pulumi.set(__self__, "dry_run", dry_run)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if nat_gateway_name and not isinstance(nat_gateway_name, str):
            raise TypeError("Expected argument 'nat_gateway_name' to be a str")
        pulumi.set(__self__, "nat_gateway_name", nat_gateway_name)
        if nat_type and not isinstance(nat_type, str):
            raise TypeError("Expected argument 'nat_type' to be a str")
        pulumi.set(__self__, "nat_type", nat_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if payment_type and not isinstance(payment_type, str):
            raise TypeError("Expected argument 'payment_type' to be a str")
        pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if specification and not isinstance(specification, str):
            raise TypeError("Expected argument 'specification' to be a str")
        pulumi.set(__self__, "specification", specification)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if total_count and not isinstance(total_count, int):
            raise TypeError("Expected argument 'total_count' to be a int")
        pulumi.set(__self__, "total_count", total_count)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[bool]:
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def gateways(self) -> Sequence['outputs.GetNatGatewaysGatewayResult']:
        """
        A list of Nat gateways. Each element contains the following attributes:
        """
        return pulumi.get(self, "gateways")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        (Optional) A list of Nat gateways IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Nat gateways names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> Optional[str]:
        """
        The name of the NAT gateway.
        """
        return pulumi.get(self, "nat_gateway_name")

    @property
    @pulumi.getter(name="natType")
    def nat_type(self) -> Optional[str]:
        """
        The type of the NAT gateway.
        """
        return pulumi.get(self, "nat_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[str]:
        """
        The billing method of the NAT gateway.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def specification(self) -> Optional[str]:
        """
        The specification of the NAT gateway.
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the NAT gateway.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        The tags of NAT gateway.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalCount")
    def total_count(self) -> int:
        return pulumi.get(self, "total_count")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNatGatewaysResult(GetNatGatewaysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNatGatewaysResult(
            dry_run=self.dry_run,
            enable_details=self.enable_details,
            gateways=self.gateways,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            nat_gateway_name=self.nat_gateway_name,
            nat_type=self.nat_type,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            payment_type=self.payment_type,
            resource_group_id=self.resource_group_id,
            specification=self.specification,
            status=self.status,
            tags=self.tags,
            total_count=self.total_count,
            vpc_id=self.vpc_id)


def get_nat_gateways(dry_run: Optional[bool] = None,
                     enable_details: Optional[bool] = None,
                     ids: Optional[Sequence[str]] = None,
                     name_regex: Optional[str] = None,
                     nat_gateway_name: Optional[str] = None,
                     nat_type: Optional[str] = None,
                     output_file: Optional[str] = None,
                     page_number: Optional[int] = None,
                     page_size: Optional[int] = None,
                     payment_type: Optional[str] = None,
                     resource_group_id: Optional[str] = None,
                     specification: Optional[str] = None,
                     status: Optional[str] = None,
                     tags: Optional[Mapping[str, str]] = None,
                     vpc_id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNatGatewaysResult:
    """
    This data source provides a list of Nat Gateways owned by an Alibaba Cloud account.

    > **NOTE:** Available in 1.37.0+.


    :param bool dry_run: Specifies whether to only precheck the request.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of NAT gateways IDs.
    :param str name_regex: A regex string to filter nat gateways by name.
    :param str nat_gateway_name: The name of NAT gateway.
    :param str nat_type: The nat type of NAT gateway. Valid values `Enhanced` and `Normal`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str payment_type: The payment type of NAT gateway. Valid values `PayAsYouGo` and `Subscription`.
    :param str resource_group_id: The resource group id of NAT gateway.
    :param str specification: The specification of NAT gateway. Valid values `Middle`, `Large`, `Small` and `XLarge.1`. Default value is `Small`.
    :param str status: The status of NAT gateway. Valid values `Available`, `Converting`, `Creating`, `Deleting` and `Modifying`.
    :param Mapping[str, str] tags: The tags of NAT gateway.
    :param str vpc_id: The ID of the VPC.
    """
    __args__ = dict()
    __args__['dryRun'] = dry_run
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['natGatewayName'] = nat_gateway_name
    __args__['natType'] = nat_type
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['paymentType'] = payment_type
    __args__['resourceGroupId'] = resource_group_id
    __args__['specification'] = specification
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getNatGateways:getNatGateways', __args__, opts=opts, typ=GetNatGatewaysResult).value

    return AwaitableGetNatGatewaysResult(
        dry_run=pulumi.get(__ret__, 'dry_run'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        nat_gateway_name=pulumi.get(__ret__, 'nat_gateway_name'),
        nat_type=pulumi.get(__ret__, 'nat_type'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        payment_type=pulumi.get(__ret__, 'payment_type'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        specification=pulumi.get(__ret__, 'specification'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        total_count=pulumi.get(__ret__, 'total_count'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_nat_gateways_output(dry_run: Optional[pulumi.Input[Optional[bool]]] = None,
                            enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                            ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                            nat_gateway_name: Optional[pulumi.Input[Optional[str]]] = None,
                            nat_type: Optional[pulumi.Input[Optional[str]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            page_number: Optional[pulumi.Input[Optional[int]]] = None,
                            page_size: Optional[pulumi.Input[Optional[int]]] = None,
                            payment_type: Optional[pulumi.Input[Optional[str]]] = None,
                            resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                            specification: Optional[pulumi.Input[Optional[str]]] = None,
                            status: Optional[pulumi.Input[Optional[str]]] = None,
                            tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                            vpc_id: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNatGatewaysResult]:
    """
    This data source provides a list of Nat Gateways owned by an Alibaba Cloud account.

    > **NOTE:** Available in 1.37.0+.


    :param bool dry_run: Specifies whether to only precheck the request.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of NAT gateways IDs.
    :param str name_regex: A regex string to filter nat gateways by name.
    :param str nat_gateway_name: The name of NAT gateway.
    :param str nat_type: The nat type of NAT gateway. Valid values `Enhanced` and `Normal`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str payment_type: The payment type of NAT gateway. Valid values `PayAsYouGo` and `Subscription`.
    :param str resource_group_id: The resource group id of NAT gateway.
    :param str specification: The specification of NAT gateway. Valid values `Middle`, `Large`, `Small` and `XLarge.1`. Default value is `Small`.
    :param str status: The status of NAT gateway. Valid values `Available`, `Converting`, `Creating`, `Deleting` and `Modifying`.
    :param Mapping[str, str] tags: The tags of NAT gateway.
    :param str vpc_id: The ID of the VPC.
    """
    __args__ = dict()
    __args__['dryRun'] = dry_run
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['natGatewayName'] = nat_gateway_name
    __args__['natType'] = nat_type
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['paymentType'] = payment_type
    __args__['resourceGroupId'] = resource_group_id
    __args__['specification'] = specification
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getNatGateways:getNatGateways', __args__, opts=opts, typ=GetNatGatewaysResult)
    return __ret__.apply(lambda __response__: GetNatGatewaysResult(
        dry_run=pulumi.get(__response__, 'dry_run'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        gateways=pulumi.get(__response__, 'gateways'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        nat_gateway_name=pulumi.get(__response__, 'nat_gateway_name'),
        nat_type=pulumi.get(__response__, 'nat_type'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        payment_type=pulumi.get(__response__, 'payment_type'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        specification=pulumi.get(__response__, 'specification'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        total_count=pulumi.get(__response__, 'total_count'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 payment_type: pulumi.Input[str],
                 zone_config: pulumi.Input['GatewayZoneConfigArgs'],
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 log_config: Optional[pulumi.Input['GatewayLogConfigArgs']] = None,
                 network_access_config: Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc: Optional[pulumi.Input['GatewayVpcArgs']] = None,
                 vswitch: Optional[pulumi.Input['GatewayVswitchArgs']] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input['GatewayZoneConfigArgs'] zone_config: Availability Zone Configuration See `zone_config` below.
        :param pulumi.Input[str] gateway_name: The name of the resource
        :param pulumi.Input['GatewayLogConfigArgs'] log_config: Log Configuration See `log_config` below.
        :param pulumi.Input['GatewayNetworkAccessConfigArgs'] network_access_config: Network Access Configuration See `network_access_config` below.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] spec: Gateway instance specifications
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        :param pulumi.Input['GatewayVpcArgs'] vpc: The VPC associated with the Gateway. See `vpc` below.
        :param pulumi.Input['GatewayVswitchArgs'] vswitch: The virtual switch associated with the Gateway. See `vswitch` below.
        """
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "zone_config", zone_config)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if log_config is not None:
            pulumi.set(__self__, "log_config", log_config)
        if network_access_config is not None:
            pulumi.set(__self__, "network_access_config", network_access_config)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)
        if vswitch is not None:
            pulumi.set(__self__, "vswitch", vswitch)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="zoneConfig")
    def zone_config(self) -> pulumi.Input['GatewayZoneConfigArgs']:
        """
        Availability Zone Configuration See `zone_config` below.
        """
        return pulumi.get(self, "zone_config")

    @zone_config.setter
    def zone_config(self, value: pulumi.Input['GatewayZoneConfigArgs']):
        pulumi.set(self, "zone_config", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter(name="logConfig")
    def log_config(self) -> Optional[pulumi.Input['GatewayLogConfigArgs']]:
        """
        Log Configuration See `log_config` below.
        """
        return pulumi.get(self, "log_config")

    @log_config.setter
    def log_config(self, value: Optional[pulumi.Input['GatewayLogConfigArgs']]):
        pulumi.set(self, "log_config", value)

    @property
    @pulumi.getter(name="networkAccessConfig")
    def network_access_config(self) -> Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']]:
        """
        Network Access Configuration See `network_access_config` below.
        """
        return pulumi.get(self, "network_access_config")

    @network_access_config.setter
    def network_access_config(self, value: Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']]):
        pulumi.set(self, "network_access_config", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[str]]:
        """
        Gateway instance specifications
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input['GatewayVpcArgs']]:
        """
        The VPC associated with the Gateway. See `vpc` below.
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input['GatewayVpcArgs']]):
        pulumi.set(self, "vpc", value)

    @property
    @pulumi.getter
    def vswitch(self) -> Optional[pulumi.Input['GatewayVswitchArgs']]:
        """
        The virtual switch associated with the Gateway. See `vswitch` below.
        """
        return pulumi.get(self, "vswitch")

    @vswitch.setter
    def vswitch(self, value: Optional[pulumi.Input['GatewayVswitchArgs']]):
        pulumi.set(self, "vswitch", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[int]] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 log_config: Optional[pulumi.Input['GatewayLogConfigArgs']] = None,
                 network_access_config: Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc: Optional[pulumi.Input['GatewayVpcArgs']] = None,
                 vswitch: Optional[pulumi.Input['GatewayVswitchArgs']] = None,
                 zone_config: Optional[pulumi.Input['GatewayZoneConfigArgs']] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input[int] create_time: The creation timestamp. Unit: milliseconds.
        :param pulumi.Input[str] gateway_name: The name of the resource
        :param pulumi.Input['GatewayLogConfigArgs'] log_config: Log Configuration See `log_config` below.
        :param pulumi.Input['GatewayNetworkAccessConfigArgs'] network_access_config: Network Access Configuration See `network_access_config` below.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] spec: Gateway instance specifications
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        :param pulumi.Input['GatewayVpcArgs'] vpc: The VPC associated with the Gateway. See `vpc` below.
        :param pulumi.Input['GatewayVswitchArgs'] vswitch: The virtual switch associated with the Gateway. See `vswitch` below.
        :param pulumi.Input['GatewayZoneConfigArgs'] zone_config: Availability Zone Configuration See `zone_config` below.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if log_config is not None:
            pulumi.set(__self__, "log_config", log_config)
        if network_access_config is not None:
            pulumi.set(__self__, "network_access_config", network_access_config)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)
        if vswitch is not None:
            pulumi.set(__self__, "vswitch", vswitch)
        if zone_config is not None:
            pulumi.set(__self__, "zone_config", zone_config)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        The creation timestamp. Unit: milliseconds.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter(name="logConfig")
    def log_config(self) -> Optional[pulumi.Input['GatewayLogConfigArgs']]:
        """
        Log Configuration See `log_config` below.
        """
        return pulumi.get(self, "log_config")

    @log_config.setter
    def log_config(self, value: Optional[pulumi.Input['GatewayLogConfigArgs']]):
        pulumi.set(self, "log_config", value)

    @property
    @pulumi.getter(name="networkAccessConfig")
    def network_access_config(self) -> Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']]:
        """
        Network Access Configuration See `network_access_config` below.
        """
        return pulumi.get(self, "network_access_config")

    @network_access_config.setter
    def network_access_config(self, value: Optional[pulumi.Input['GatewayNetworkAccessConfigArgs']]):
        pulumi.set(self, "network_access_config", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[str]]:
        """
        Gateway instance specifications
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input['GatewayVpcArgs']]:
        """
        The VPC associated with the Gateway. See `vpc` below.
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input['GatewayVpcArgs']]):
        pulumi.set(self, "vpc", value)

    @property
    @pulumi.getter
    def vswitch(self) -> Optional[pulumi.Input['GatewayVswitchArgs']]:
        """
        The virtual switch associated with the Gateway. See `vswitch` below.
        """
        return pulumi.get(self, "vswitch")

    @vswitch.setter
    def vswitch(self, value: Optional[pulumi.Input['GatewayVswitchArgs']]):
        pulumi.set(self, "vswitch", value)

    @property
    @pulumi.getter(name="zoneConfig")
    def zone_config(self) -> Optional[pulumi.Input['GatewayZoneConfigArgs']]:
        """
        Availability Zone Configuration See `zone_config` below.
        """
        return pulumi.get(self, "zone_config")

    @zone_config.setter
    def zone_config(self, value: Optional[pulumi.Input['GatewayZoneConfigArgs']]):
        pulumi.set(self, "zone_config", value)


class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 log_config: Optional[pulumi.Input[Union['GatewayLogConfigArgs', 'GatewayLogConfigArgsDict']]] = None,
                 network_access_config: Optional[pulumi.Input[Union['GatewayNetworkAccessConfigArgs', 'GatewayNetworkAccessConfigArgsDict']]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc: Optional[pulumi.Input[Union['GatewayVpcArgs', 'GatewayVpcArgsDict']]] = None,
                 vswitch: Optional[pulumi.Input[Union['GatewayVswitchArgs', 'GatewayVswitchArgsDict']]] = None,
                 zone_config: Optional[pulumi.Input[Union['GatewayZoneConfigArgs', 'GatewayZoneConfigArgsDict']]] = None,
                 __props__=None):
        """
        ## Import

        APIG Gateway can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apig/gateway:Gateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] gateway_name: The name of the resource
        :param pulumi.Input[Union['GatewayLogConfigArgs', 'GatewayLogConfigArgsDict']] log_config: Log Configuration See `log_config` below.
        :param pulumi.Input[Union['GatewayNetworkAccessConfigArgs', 'GatewayNetworkAccessConfigArgsDict']] network_access_config: Network Access Configuration See `network_access_config` below.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] spec: Gateway instance specifications
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        :param pulumi.Input[Union['GatewayVpcArgs', 'GatewayVpcArgsDict']] vpc: The VPC associated with the Gateway. See `vpc` below.
        :param pulumi.Input[Union['GatewayVswitchArgs', 'GatewayVswitchArgsDict']] vswitch: The virtual switch associated with the Gateway. See `vswitch` below.
        :param pulumi.Input[Union['GatewayZoneConfigArgs', 'GatewayZoneConfigArgsDict']] zone_config: Availability Zone Configuration See `zone_config` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        APIG Gateway can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apig/gateway:Gateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 log_config: Optional[pulumi.Input[Union['GatewayLogConfigArgs', 'GatewayLogConfigArgsDict']]] = None,
                 network_access_config: Optional[pulumi.Input[Union['GatewayNetworkAccessConfigArgs', 'GatewayNetworkAccessConfigArgsDict']]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc: Optional[pulumi.Input[Union['GatewayVpcArgs', 'GatewayVpcArgsDict']]] = None,
                 vswitch: Optional[pulumi.Input[Union['GatewayVswitchArgs', 'GatewayVswitchArgsDict']]] = None,
                 zone_config: Optional[pulumi.Input[Union['GatewayZoneConfigArgs', 'GatewayZoneConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            __props__.__dict__["gateway_name"] = gateway_name
            __props__.__dict__["log_config"] = log_config
            __props__.__dict__["network_access_config"] = network_access_config
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["spec"] = spec
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc"] = vpc
            __props__.__dict__["vswitch"] = vswitch
            if zone_config is None and not opts.urn:
                raise TypeError("Missing required property 'zone_config'")
            __props__.__dict__["zone_config"] = zone_config
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Gateway, __self__).__init__(
            'alicloud:apig/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            gateway_name: Optional[pulumi.Input[str]] = None,
            log_config: Optional[pulumi.Input[Union['GatewayLogConfigArgs', 'GatewayLogConfigArgsDict']]] = None,
            network_access_config: Optional[pulumi.Input[Union['GatewayNetworkAccessConfigArgs', 'GatewayNetworkAccessConfigArgsDict']]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            spec: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            vpc: Optional[pulumi.Input[Union['GatewayVpcArgs', 'GatewayVpcArgsDict']]] = None,
            vswitch: Optional[pulumi.Input[Union['GatewayVswitchArgs', 'GatewayVswitchArgsDict']]] = None,
            zone_config: Optional[pulumi.Input[Union['GatewayZoneConfigArgs', 'GatewayZoneConfigArgsDict']]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] create_time: The creation timestamp. Unit: milliseconds.
        :param pulumi.Input[str] gateway_name: The name of the resource
        :param pulumi.Input[Union['GatewayLogConfigArgs', 'GatewayLogConfigArgsDict']] log_config: Log Configuration See `log_config` below.
        :param pulumi.Input[Union['GatewayNetworkAccessConfigArgs', 'GatewayNetworkAccessConfigArgsDict']] network_access_config: Network Access Configuration See `network_access_config` below.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] spec: Gateway instance specifications
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        :param pulumi.Input[Union['GatewayVpcArgs', 'GatewayVpcArgsDict']] vpc: The VPC associated with the Gateway. See `vpc` below.
        :param pulumi.Input[Union['GatewayVswitchArgs', 'GatewayVswitchArgsDict']] vswitch: The virtual switch associated with the Gateway. See `vswitch` below.
        :param pulumi.Input[Union['GatewayZoneConfigArgs', 'GatewayZoneConfigArgsDict']] zone_config: Availability Zone Configuration See `zone_config` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["gateway_name"] = gateway_name
        __props__.__dict__["log_config"] = log_config
        __props__.__dict__["network_access_config"] = network_access_config
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc"] = vpc
        __props__.__dict__["vswitch"] = vswitch
        __props__.__dict__["zone_config"] = zone_config
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        The creation timestamp. Unit: milliseconds.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter(name="logConfig")
    def log_config(self) -> pulumi.Output[Optional['outputs.GatewayLogConfig']]:
        """
        Log Configuration See `log_config` below.
        """
        return pulumi.get(self, "log_config")

    @property
    @pulumi.getter(name="networkAccessConfig")
    def network_access_config(self) -> pulumi.Output[Optional['outputs.GatewayNetworkAccessConfig']]:
        """
        Network Access Configuration See `network_access_config` below.
        """
        return pulumi.get(self, "network_access_config")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[Optional[str]]:
        """
        Gateway instance specifications
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def vpc(self) -> pulumi.Output[Optional['outputs.GatewayVpc']]:
        """
        The VPC associated with the Gateway. See `vpc` below.
        """
        return pulumi.get(self, "vpc")

    @property
    @pulumi.getter
    def vswitch(self) -> pulumi.Output[Optional['outputs.GatewayVswitch']]:
        """
        The virtual switch associated with the Gateway. See `vswitch` below.
        """
        return pulumi.get(self, "vswitch")

    @property
    @pulumi.getter(name="zoneConfig")
    def zone_config(self) -> pulumi.Output['outputs.GatewayZoneConfig']:
        """
        Availability Zone Configuration See `zone_config` below.
        """
        return pulumi.get(self, "zone_config")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRulesResult',
    'AwaitableGetRulesResult',
    'get_rules',
    'get_rules_output',
]

@pulumi.output_type
class GetRulesResult:
    """
    A collection of values returned by getRules.
    """
    def __init__(__self__, config_rule_state=None, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, risk_level=None, rule_name=None, rules=None, status=None):
        if config_rule_state and not isinstance(config_rule_state, str):
            raise TypeError("Expected argument 'config_rule_state' to be a str")
        pulumi.set(__self__, "config_rule_state", config_rule_state)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if risk_level and not isinstance(risk_level, int):
            raise TypeError("Expected argument 'risk_level' to be a int")
        pulumi.set(__self__, "risk_level", risk_level)
        if rule_name and not isinstance(rule_name, str):
            raise TypeError("Expected argument 'rule_name' to be a str")
        pulumi.set(__self__, "rule_name", rule_name)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="configRuleState")
    @_utilities.deprecated("""Field 'config_rule_state' has been deprecated from provider version 1.124.1. New field 'status' instead.""")
    def config_rule_state(self) -> Optional[str]:
        """
        The state of the Config Rule.
        """
        return pulumi.get(self, "config_rule_state")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Config Rule IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Config Rule names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> Optional[int]:
        """
        The risk level of the Config Rule.
        """
        return pulumi.get(self, "risk_level")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[str]:
        """
        The name of the Config Rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetRulesRuleResult']:
        """
        A list of Config Rules. Each element contains the following attributes:
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        (Available since v1.124.1) The status of config rule.
        """
        return pulumi.get(self, "status")


class AwaitableGetRulesResult(GetRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRulesResult(
            config_rule_state=self.config_rule_state,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            risk_level=self.risk_level,
            rule_name=self.rule_name,
            rules=self.rules,
            status=self.status)


def get_rules(config_rule_state: Optional[str] = None,
              enable_details: Optional[bool] = None,
              ids: Optional[Sequence[str]] = None,
              name_regex: Optional[str] = None,
              output_file: Optional[str] = None,
              risk_level: Optional[int] = None,
              rule_name: Optional[str] = None,
              status: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRulesResult:
    """
    This data source provides the Config Rules of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.99.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.cfg.get_rules(ids=["cr-ed4bad756057********"],
        name_regex="tftest")
    pulumi.export("firstConfigRuleId", example.rules[0].id)
    ```


    :param str config_rule_state: Field `config_rule_state` has been deprecated from provider version 1.124.1. New field `status` instead.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Config Rule IDs.
    :param str name_regex: A regex string to filter results by rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int risk_level: The risk level of Config Rule. Valid values: `1`: Critical ,`2`: Warning , `3`: Info.
    :param str rule_name: The name of config rule.
    :param str status: The status of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
    """
    __args__ = dict()
    __args__['configRuleState'] = config_rule_state
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['riskLevel'] = risk_level
    __args__['ruleName'] = rule_name
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cfg/getRules:getRules', __args__, opts=opts, typ=GetRulesResult).value

    return AwaitableGetRulesResult(
        config_rule_state=pulumi.get(__ret__, 'config_rule_state'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        risk_level=pulumi.get(__ret__, 'risk_level'),
        rule_name=pulumi.get(__ret__, 'rule_name'),
        rules=pulumi.get(__ret__, 'rules'),
        status=pulumi.get(__ret__, 'status'))
def get_rules_output(config_rule_state: Optional[pulumi.Input[Optional[str]]] = None,
                     enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                     ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                     name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                     output_file: Optional[pulumi.Input[Optional[str]]] = None,
                     risk_level: Optional[pulumi.Input[Optional[int]]] = None,
                     rule_name: Optional[pulumi.Input[Optional[str]]] = None,
                     status: Optional[pulumi.Input[Optional[str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRulesResult]:
    """
    This data source provides the Config Rules of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.99.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.cfg.get_rules(ids=["cr-ed4bad756057********"],
        name_regex="tftest")
    pulumi.export("firstConfigRuleId", example.rules[0].id)
    ```


    :param str config_rule_state: Field `config_rule_state` has been deprecated from provider version 1.124.1. New field `status` instead.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Config Rule IDs.
    :param str name_regex: A regex string to filter results by rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int risk_level: The risk level of Config Rule. Valid values: `1`: Critical ,`2`: Warning , `3`: Info.
    :param str rule_name: The name of config rule.
    :param str status: The status of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
    """
    __args__ = dict()
    __args__['configRuleState'] = config_rule_state
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['riskLevel'] = risk_level
    __args__['ruleName'] = rule_name
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cfg/getRules:getRules', __args__, opts=opts, typ=GetRulesResult)
    return __ret__.apply(lambda __response__: GetRulesResult(
        config_rule_state=pulumi.get(__response__, 'config_rule_state'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        risk_level=pulumi.get(__response__, 'risk_level'),
        rule_name=pulumi.get(__response__, 'rule_name'),
        rules=pulumi.get(__response__, 'rules'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServiceTopicArgs', 'ServiceTopic']

@pulumi.input_type
class ServiceTopicArgs:
    def __init__(__self__, *,
                 topic_name: pulumi.Input[str],
                 enable_logging: Optional[pulumi.Input[bool]] = None,
                 logging_enabled: Optional[pulumi.Input[bool]] = None,
                 max_message_size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ServiceTopic resource.
        :param pulumi.Input[str] topic_name: The name of the topic.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[bool] enable_logging: Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        :param pulumi.Input[bool] logging_enabled: . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        :param pulumi.Input[int] max_message_size: The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "topic_name", topic_name)
        if enable_logging is not None:
            pulumi.set(__self__, "enable_logging", enable_logging)
        if logging_enabled is not None:
            warnings.warn("""Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""", DeprecationWarning)
            pulumi.log.warn("""logging_enabled is deprecated: Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""")
        if logging_enabled is not None:
            pulumi.set(__self__, "logging_enabled", logging_enabled)
        if max_message_size is not None:
            pulumi.set(__self__, "max_message_size", max_message_size)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[str]:
        """
        The name of the topic.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="enableLogging")
    def enable_logging(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_logging")

    @enable_logging.setter
    def enable_logging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_logging", value)

    @property
    @pulumi.getter(name="loggingEnabled")
    @_utilities.deprecated("""Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""")
    def logging_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        """
        return pulumi.get(self, "logging_enabled")

    @logging_enabled.setter
    def logging_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "logging_enabled", value)

    @property
    @pulumi.getter(name="maxMessageSize")
    def max_message_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        """
        return pulumi.get(self, "max_message_size")

    @max_message_size.setter
    def max_message_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_message_size", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ServiceTopicState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 enable_logging: Optional[pulumi.Input[bool]] = None,
                 logging_enabled: Optional[pulumi.Input[bool]] = None,
                 max_message_size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ServiceTopic resources.
        :param pulumi.Input[str] create_time: (Available since v1.241.0) The time when the topic was created.
        :param pulumi.Input[bool] enable_logging: Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        :param pulumi.Input[bool] logging_enabled: . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        :param pulumi.Input[int] max_message_size: The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] topic_name: The name of the topic.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if enable_logging is not None:
            pulumi.set(__self__, "enable_logging", enable_logging)
        if logging_enabled is not None:
            warnings.warn("""Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""", DeprecationWarning)
            pulumi.log.warn("""logging_enabled is deprecated: Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""")
        if logging_enabled is not None:
            pulumi.set(__self__, "logging_enabled", logging_enabled)
        if max_message_size is not None:
            pulumi.set(__self__, "max_message_size", max_message_size)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.241.0) The time when the topic was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="enableLogging")
    def enable_logging(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_logging")

    @enable_logging.setter
    def enable_logging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_logging", value)

    @property
    @pulumi.getter(name="loggingEnabled")
    @_utilities.deprecated("""Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""")
    def logging_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        """
        return pulumi.get(self, "logging_enabled")

    @logging_enabled.setter
    def logging_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "logging_enabled", value)

    @property
    @pulumi.getter(name="maxMessageSize")
    def max_message_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        """
        return pulumi.get(self, "max_message_size")

    @max_message_size.setter
    def max_message_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_message_size", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the topic.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic_name", value)


class ServiceTopic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_logging: Optional[pulumi.Input[bool]] = None,
                 logging_enabled: Optional[pulumi.Input[bool]] = None,
                 max_message_size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Message Service Topic resource.

        For information about Message Service Topic and how to use it, see [What is Topic](https://www.alibabacloud.com/help/en/message-service/latest/createtopic).

        > **NOTE:** Available since v1.188.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.message.ServiceTopic("default",
            topic_name=name,
            max_message_size=16888,
            enable_logging=True)
        ```

        ## Import

        Message Service Topic can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:message/serviceTopic:ServiceTopic example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_logging: Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        :param pulumi.Input[bool] logging_enabled: . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        :param pulumi.Input[int] max_message_size: The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] topic_name: The name of the topic.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceTopicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Message Service Topic resource.

        For information about Message Service Topic and how to use it, see [What is Topic](https://www.alibabacloud.com/help/en/message-service/latest/createtopic).

        > **NOTE:** Available since v1.188.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.message.ServiceTopic("default",
            topic_name=name,
            max_message_size=16888,
            enable_logging=True)
        ```

        ## Import

        Message Service Topic can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:message/serviceTopic:ServiceTopic example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceTopicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceTopicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_logging: Optional[pulumi.Input[bool]] = None,
                 logging_enabled: Optional[pulumi.Input[bool]] = None,
                 max_message_size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceTopicArgs.__new__(ServiceTopicArgs)

            __props__.__dict__["enable_logging"] = enable_logging
            __props__.__dict__["logging_enabled"] = logging_enabled
            __props__.__dict__["max_message_size"] = max_message_size
            __props__.__dict__["tags"] = tags
            if topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'topic_name'")
            __props__.__dict__["topic_name"] = topic_name
            __props__.__dict__["create_time"] = None
        super(ServiceTopic, __self__).__init__(
            'alicloud:message/serviceTopic:ServiceTopic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            enable_logging: Optional[pulumi.Input[bool]] = None,
            logging_enabled: Optional[pulumi.Input[bool]] = None,
            max_message_size: Optional[pulumi.Input[int]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            topic_name: Optional[pulumi.Input[str]] = None) -> 'ServiceTopic':
        """
        Get an existing ServiceTopic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: (Available since v1.241.0) The time when the topic was created.
        :param pulumi.Input[bool] enable_logging: Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        :param pulumi.Input[bool] logging_enabled: . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        :param pulumi.Input[int] max_message_size: The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] topic_name: The name of the topic.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceTopicState.__new__(_ServiceTopicState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["enable_logging"] = enable_logging
        __props__.__dict__["logging_enabled"] = logging_enabled
        __props__.__dict__["max_message_size"] = max_message_size
        __props__.__dict__["tags"] = tags
        __props__.__dict__["topic_name"] = topic_name
        return ServiceTopic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        (Available since v1.241.0) The time when the topic was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="enableLogging")
    def enable_logging(self) -> pulumi.Output[bool]:
        """
        Specifies whether to enable the logging feature. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_logging")

    @property
    @pulumi.getter(name="loggingEnabled")
    @_utilities.deprecated("""Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.""")
    def logging_enabled(self) -> pulumi.Output[bool]:
        """
        . Field `logging_enabled` has been deprecated from provider version 1.241.0. New field `enable_logging` instead.
        """
        return pulumi.get(self, "logging_enabled")

    @property
    @pulumi.getter(name="maxMessageSize")
    def max_message_size(self) -> pulumi.Output[int]:
        """
        The maximum length of the message that is sent to the topic. Default value: `65536`. Valid values: `1024` to `65536`. Unit: bytes.
        """
        return pulumi.get(self, "max_message_size")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Output[str]:
        """
        The name of the topic.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "topic_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'JobJobMonitorInfoArgs',
    'JobJobMonitorInfoArgsDict',
    'JobJobMonitorInfoContactInfoArgs',
    'JobJobMonitorInfoContactInfoArgsDict',
    'JobJobMonitorInfoMonitorConfigArgs',
    'JobJobMonitorInfoMonitorConfigArgsDict',
    'JobMapTaskXattrsArgs',
    'JobMapTaskXattrsArgsDict',
    'JobTimeConfigArgs',
    'JobTimeConfigArgsDict',
]

MYPY = False

if not MYPY:
    class JobJobMonitorInfoArgsDict(TypedDict):
        contact_infos: NotRequired[pulumi.Input[Sequence[pulumi.Input['JobJobMonitorInfoContactInfoArgsDict']]]]
        """
        Contact information. See `contact_info` below.
        """
        monitor_config: NotRequired[pulumi.Input['JobJobMonitorInfoMonitorConfigArgsDict']]
        """
        Alarm switch and threshold configuration. See `monitor_config` below.
        """
elif False:
    JobJobMonitorInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class JobJobMonitorInfoArgs:
    def __init__(__self__, *,
                 contact_infos: Optional[pulumi.Input[Sequence[pulumi.Input['JobJobMonitorInfoContactInfoArgs']]]] = None,
                 monitor_config: Optional[pulumi.Input['JobJobMonitorInfoMonitorConfigArgs']] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['JobJobMonitorInfoContactInfoArgs']]] contact_infos: Contact information. See `contact_info` below.
        :param pulumi.Input['JobJobMonitorInfoMonitorConfigArgs'] monitor_config: Alarm switch and threshold configuration. See `monitor_config` below.
        """
        if contact_infos is not None:
            pulumi.set(__self__, "contact_infos", contact_infos)
        if monitor_config is not None:
            pulumi.set(__self__, "monitor_config", monitor_config)

    @property
    @pulumi.getter(name="contactInfos")
    def contact_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobJobMonitorInfoContactInfoArgs']]]]:
        """
        Contact information. See `contact_info` below.
        """
        return pulumi.get(self, "contact_infos")

    @contact_infos.setter
    def contact_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobJobMonitorInfoContactInfoArgs']]]]):
        pulumi.set(self, "contact_infos", value)

    @property
    @pulumi.getter(name="monitorConfig")
    def monitor_config(self) -> Optional[pulumi.Input['JobJobMonitorInfoMonitorConfigArgs']]:
        """
        Alarm switch and threshold configuration. See `monitor_config` below.
        """
        return pulumi.get(self, "monitor_config")

    @monitor_config.setter
    def monitor_config(self, value: Optional[pulumi.Input['JobJobMonitorInfoMonitorConfigArgs']]):
        pulumi.set(self, "monitor_config", value)


if not MYPY:
    class JobJobMonitorInfoContactInfoArgsDict(TypedDict):
        ding: NotRequired[pulumi.Input[str]]
        """
        DingTalk swarm robot webhook address
        """
        user_mail: NotRequired[pulumi.Input[str]]
        """
        User Email Address
        """
        user_name: NotRequired[pulumi.Input[str]]
        """
        The user name
        """
        user_phone: NotRequired[pulumi.Input[str]]
        """
        The user's mobile phone number
        """
elif False:
    JobJobMonitorInfoContactInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class JobJobMonitorInfoContactInfoArgs:
    def __init__(__self__, *,
                 ding: Optional[pulumi.Input[str]] = None,
                 user_mail: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 user_phone: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] ding: DingTalk swarm robot webhook address
        :param pulumi.Input[str] user_mail: User Email Address
        :param pulumi.Input[str] user_name: The user name
        :param pulumi.Input[str] user_phone: The user's mobile phone number
        """
        if ding is not None:
            pulumi.set(__self__, "ding", ding)
        if user_mail is not None:
            pulumi.set(__self__, "user_mail", user_mail)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if user_phone is not None:
            pulumi.set(__self__, "user_phone", user_phone)

    @property
    @pulumi.getter
    def ding(self) -> Optional[pulumi.Input[str]]:
        """
        DingTalk swarm robot webhook address
        """
        return pulumi.get(self, "ding")

    @ding.setter
    def ding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ding", value)

    @property
    @pulumi.getter(name="userMail")
    def user_mail(self) -> Optional[pulumi.Input[str]]:
        """
        User Email Address
        """
        return pulumi.get(self, "user_mail")

    @user_mail.setter
    def user_mail(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_mail", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The user name
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPhone")
    def user_phone(self) -> Optional[pulumi.Input[str]]:
        """
        The user's mobile phone number
        """
        return pulumi.get(self, "user_phone")

    @user_phone.setter
    def user_phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_phone", value)


if not MYPY:
    class JobJobMonitorInfoMonitorConfigArgsDict(TypedDict):
        fail_enable: NotRequired[pulumi.Input[bool]]
        """
        Enable failure alarm
        """
        miss_worker_enable: NotRequired[pulumi.Input[bool]]
        """
        Whether no available Machine alarm is on
        """
        send_channel: NotRequired[pulumi.Input[str]]
        """
        Alarm sending form
        - sms: sms alarm
        - phone: phone alarm
        - mail: mail alarm
        - webhook:webhook alarm
        """
        timeout: NotRequired[pulumi.Input[int]]
        """
        Timeout threshold, unit s, default 7200.
        """
        timeout_enable: NotRequired[pulumi.Input[bool]]
        """
        Time-out alarm switch. The values are as follows:
        """
        timeout_kill_enable: NotRequired[pulumi.Input[bool]]
        """
        The trigger switch is terminated by timeout and is turned off by default.
        """
elif False:
    JobJobMonitorInfoMonitorConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class JobJobMonitorInfoMonitorConfigArgs:
    def __init__(__self__, *,
                 fail_enable: Optional[pulumi.Input[bool]] = None,
                 miss_worker_enable: Optional[pulumi.Input[bool]] = None,
                 send_channel: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None,
                 timeout_enable: Optional[pulumi.Input[bool]] = None,
                 timeout_kill_enable: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] fail_enable: Enable failure alarm
        :param pulumi.Input[bool] miss_worker_enable: Whether no available Machine alarm is on
        :param pulumi.Input[str] send_channel: Alarm sending form
               - sms: sms alarm
               - phone: phone alarm
               - mail: mail alarm
               - webhook:webhook alarm
        :param pulumi.Input[int] timeout: Timeout threshold, unit s, default 7200.
        :param pulumi.Input[bool] timeout_enable: Time-out alarm switch. The values are as follows:
        :param pulumi.Input[bool] timeout_kill_enable: The trigger switch is terminated by timeout and is turned off by default.
        """
        if fail_enable is not None:
            pulumi.set(__self__, "fail_enable", fail_enable)
        if miss_worker_enable is not None:
            pulumi.set(__self__, "miss_worker_enable", miss_worker_enable)
        if send_channel is not None:
            pulumi.set(__self__, "send_channel", send_channel)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if timeout_enable is not None:
            pulumi.set(__self__, "timeout_enable", timeout_enable)
        if timeout_kill_enable is not None:
            pulumi.set(__self__, "timeout_kill_enable", timeout_kill_enable)

    @property
    @pulumi.getter(name="failEnable")
    def fail_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable failure alarm
        """
        return pulumi.get(self, "fail_enable")

    @fail_enable.setter
    def fail_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "fail_enable", value)

    @property
    @pulumi.getter(name="missWorkerEnable")
    def miss_worker_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether no available Machine alarm is on
        """
        return pulumi.get(self, "miss_worker_enable")

    @miss_worker_enable.setter
    def miss_worker_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "miss_worker_enable", value)

    @property
    @pulumi.getter(name="sendChannel")
    def send_channel(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm sending form
        - sms: sms alarm
        - phone: phone alarm
        - mail: mail alarm
        - webhook:webhook alarm
        """
        return pulumi.get(self, "send_channel")

    @send_channel.setter
    def send_channel(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "send_channel", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Timeout threshold, unit s, default 7200.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter(name="timeoutEnable")
    def timeout_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Time-out alarm switch. The values are as follows:
        """
        return pulumi.get(self, "timeout_enable")

    @timeout_enable.setter
    def timeout_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "timeout_enable", value)

    @property
    @pulumi.getter(name="timeoutKillEnable")
    def timeout_kill_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        The trigger switch is terminated by timeout and is turned off by default.
        """
        return pulumi.get(self, "timeout_kill_enable")

    @timeout_kill_enable.setter
    def timeout_kill_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "timeout_kill_enable", value)


if not MYPY:
    class JobMapTaskXattrsArgsDict(TypedDict):
        consumer_size: NotRequired[pulumi.Input[int]]
        """
        The number of threads to execute a single trigger. The default value is 5.
        """
        dispatcher_size: NotRequired[pulumi.Input[int]]
        """
        The number of subtask distribution threads. The default value is 5.
        """
        page_size: NotRequired[pulumi.Input[int]]
        """
        The number of sub-tasks pulled by a parallel task at a time. The default value is 100.
        """
        queue_size: NotRequired[pulumi.Input[int]]
        """
        The upper limit of the sub-task queue cache. The default value is 10000.
        """
        task_attempt_interval: NotRequired[pulumi.Input[int]]
        """
        Subtask failure retry interval.
        """
        task_max_attempt: NotRequired[pulumi.Input[int]]
        """
        The number of failed sub-task retries.
        """
elif False:
    JobMapTaskXattrsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class JobMapTaskXattrsArgs:
    def __init__(__self__, *,
                 consumer_size: Optional[pulumi.Input[int]] = None,
                 dispatcher_size: Optional[pulumi.Input[int]] = None,
                 page_size: Optional[pulumi.Input[int]] = None,
                 queue_size: Optional[pulumi.Input[int]] = None,
                 task_attempt_interval: Optional[pulumi.Input[int]] = None,
                 task_max_attempt: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] consumer_size: The number of threads to execute a single trigger. The default value is 5.
        :param pulumi.Input[int] dispatcher_size: The number of subtask distribution threads. The default value is 5.
        :param pulumi.Input[int] page_size: The number of sub-tasks pulled by a parallel task at a time. The default value is 100.
        :param pulumi.Input[int] queue_size: The upper limit of the sub-task queue cache. The default value is 10000.
        :param pulumi.Input[int] task_attempt_interval: Subtask failure retry interval.
        :param pulumi.Input[int] task_max_attempt: The number of failed sub-task retries.
        """
        if consumer_size is not None:
            pulumi.set(__self__, "consumer_size", consumer_size)
        if dispatcher_size is not None:
            pulumi.set(__self__, "dispatcher_size", dispatcher_size)
        if page_size is not None:
            pulumi.set(__self__, "page_size", page_size)
        if queue_size is not None:
            pulumi.set(__self__, "queue_size", queue_size)
        if task_attempt_interval is not None:
            pulumi.set(__self__, "task_attempt_interval", task_attempt_interval)
        if task_max_attempt is not None:
            pulumi.set(__self__, "task_max_attempt", task_max_attempt)

    @property
    @pulumi.getter(name="consumerSize")
    def consumer_size(self) -> Optional[pulumi.Input[int]]:
        """
        The number of threads to execute a single trigger. The default value is 5.
        """
        return pulumi.get(self, "consumer_size")

    @consumer_size.setter
    def consumer_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "consumer_size", value)

    @property
    @pulumi.getter(name="dispatcherSize")
    def dispatcher_size(self) -> Optional[pulumi.Input[int]]:
        """
        The number of subtask distribution threads. The default value is 5.
        """
        return pulumi.get(self, "dispatcher_size")

    @dispatcher_size.setter
    def dispatcher_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "dispatcher_size", value)

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[pulumi.Input[int]]:
        """
        The number of sub-tasks pulled by a parallel task at a time. The default value is 100.
        """
        return pulumi.get(self, "page_size")

    @page_size.setter
    def page_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "page_size", value)

    @property
    @pulumi.getter(name="queueSize")
    def queue_size(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit of the sub-task queue cache. The default value is 10000.
        """
        return pulumi.get(self, "queue_size")

    @queue_size.setter
    def queue_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "queue_size", value)

    @property
    @pulumi.getter(name="taskAttemptInterval")
    def task_attempt_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Subtask failure retry interval.
        """
        return pulumi.get(self, "task_attempt_interval")

    @task_attempt_interval.setter
    def task_attempt_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "task_attempt_interval", value)

    @property
    @pulumi.getter(name="taskMaxAttempt")
    def task_max_attempt(self) -> Optional[pulumi.Input[int]]:
        """
        The number of failed sub-task retries.
        """
        return pulumi.get(self, "task_max_attempt")

    @task_max_attempt.setter
    def task_max_attempt(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "task_max_attempt", value)


if not MYPY:
    class JobTimeConfigArgsDict(TypedDict):
        time_type: pulumi.Input[int]
        """
        Time configuration type. Currently, the following time types are supported:
        """
        calendar: NotRequired[pulumi.Input[str]]
        """
        The cron type can optionally fill in a custom calendar.
        """
        data_offset: NotRequired[pulumi.Input[int]]
        """
        Cron type can choose time offset, unit s.
        """
        time_expression: NotRequired[pulumi.Input[str]]
        """
        Time expressions. Currently, the following types of time expressions are supported:
        """
elif False:
    JobTimeConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class JobTimeConfigArgs:
    def __init__(__self__, *,
                 time_type: pulumi.Input[int],
                 calendar: Optional[pulumi.Input[str]] = None,
                 data_offset: Optional[pulumi.Input[int]] = None,
                 time_expression: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] time_type: Time configuration type. Currently, the following time types are supported:
        :param pulumi.Input[str] calendar: The cron type can optionally fill in a custom calendar.
        :param pulumi.Input[int] data_offset: Cron type can choose time offset, unit s.
        :param pulumi.Input[str] time_expression: Time expressions. Currently, the following types of time expressions are supported:
        """
        pulumi.set(__self__, "time_type", time_type)
        if calendar is not None:
            pulumi.set(__self__, "calendar", calendar)
        if data_offset is not None:
            pulumi.set(__self__, "data_offset", data_offset)
        if time_expression is not None:
            pulumi.set(__self__, "time_expression", time_expression)

    @property
    @pulumi.getter(name="timeType")
    def time_type(self) -> pulumi.Input[int]:
        """
        Time configuration type. Currently, the following time types are supported:
        """
        return pulumi.get(self, "time_type")

    @time_type.setter
    def time_type(self, value: pulumi.Input[int]):
        pulumi.set(self, "time_type", value)

    @property
    @pulumi.getter
    def calendar(self) -> Optional[pulumi.Input[str]]:
        """
        The cron type can optionally fill in a custom calendar.
        """
        return pulumi.get(self, "calendar")

    @calendar.setter
    def calendar(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "calendar", value)

    @property
    @pulumi.getter(name="dataOffset")
    def data_offset(self) -> Optional[pulumi.Input[int]]:
        """
        Cron type can choose time offset, unit s.
        """
        return pulumi.get(self, "data_offset")

    @data_offset.setter
    def data_offset(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "data_offset", value)

    @property
    @pulumi.getter(name="timeExpression")
    def time_expression(self) -> Optional[pulumi.Input[str]]:
        """
        Time expressions. Currently, the following types of time expressions are supported:
        """
        return pulumi.get(self, "time_expression")

    @time_expression.setter
    def time_expression(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_expression", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpsecServersResult',
    'AwaitableGetIpsecServersResult',
    'get_ipsec_servers',
    'get_ipsec_servers_output',
]

@pulumi.output_type
class GetIpsecServersResult:
    """
    A collection of values returned by getIpsecServers.
    """
    def __init__(__self__, id=None, ids=None, ipsec_server_name=None, name_regex=None, names=None, output_file=None, servers=None, vpn_gateway_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if ipsec_server_name and not isinstance(ipsec_server_name, str):
            raise TypeError("Expected argument 'ipsec_server_name' to be a str")
        pulumi.set(__self__, "ipsec_server_name", ipsec_server_name)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if servers and not isinstance(servers, list):
            raise TypeError("Expected argument 'servers' to be a list")
        pulumi.set(__self__, "servers", servers)
        if vpn_gateway_id and not isinstance(vpn_gateway_id, str):
            raise TypeError("Expected argument 'vpn_gateway_id' to be a str")
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="ipsecServerName")
    def ipsec_server_name(self) -> Optional[str]:
        return pulumi.get(self, "ipsec_server_name")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def servers(self) -> Sequence['outputs.GetIpsecServersServerResult']:
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[str]:
        return pulumi.get(self, "vpn_gateway_id")


class AwaitableGetIpsecServersResult(GetIpsecServersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpsecServersResult(
            id=self.id,
            ids=self.ids,
            ipsec_server_name=self.ipsec_server_name,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            servers=self.servers,
            vpn_gateway_id=self.vpn_gateway_id)


def get_ipsec_servers(ids: Optional[Sequence[str]] = None,
                      ipsec_server_name: Optional[str] = None,
                      name_regex: Optional[str] = None,
                      output_file: Optional[str] = None,
                      vpn_gateway_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpsecServersResult:
    """
    This data source provides the Vpn Ipsec Servers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.161.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_ipsec_servers(ids=["example_id"])
    pulumi.export("vpnIpsecServerId1", ids.servers[0].id)
    name_regex = alicloud.vpc.get_ipsec_servers(name_regex="^my-IpsecServer")
    pulumi.export("vpnIpsecServerId2", name_regex.servers[0].id)
    ```


    :param Sequence[str] ids: A list of Ipsec Server IDs.
    :param str ipsec_server_name: The name of the IPsec server.
    :param str name_regex: A regex string to filter results by Ipsec Server name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str vpn_gateway_id: The ID of the VPN gateway.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipsecServerName'] = ipsec_server_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getIpsecServers:getIpsecServers', __args__, opts=opts, typ=GetIpsecServersResult).value

    return AwaitableGetIpsecServersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        ipsec_server_name=pulumi.get(__ret__, 'ipsec_server_name'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        servers=pulumi.get(__ret__, 'servers'),
        vpn_gateway_id=pulumi.get(__ret__, 'vpn_gateway_id'))
def get_ipsec_servers_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             ipsec_server_name: Optional[pulumi.Input[Optional[str]]] = None,
                             name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             vpn_gateway_id: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpsecServersResult]:
    """
    This data source provides the Vpn Ipsec Servers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.161.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_ipsec_servers(ids=["example_id"])
    pulumi.export("vpnIpsecServerId1", ids.servers[0].id)
    name_regex = alicloud.vpc.get_ipsec_servers(name_regex="^my-IpsecServer")
    pulumi.export("vpnIpsecServerId2", name_regex.servers[0].id)
    ```


    :param Sequence[str] ids: A list of Ipsec Server IDs.
    :param str ipsec_server_name: The name of the IPsec server.
    :param str name_regex: A regex string to filter results by Ipsec Server name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str vpn_gateway_id: The ID of the VPN gateway.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipsecServerName'] = ipsec_server_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getIpsecServers:getIpsecServers', __args__, opts=opts, typ=GetIpsecServersResult)
    return __ret__.apply(lambda __response__: GetIpsecServersResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        ipsec_server_name=pulumi.get(__response__, 'ipsec_server_name'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        servers=pulumi.get(__response__, 'servers'),
        vpn_gateway_id=pulumi.get(__response__, 'vpn_gateway_id')))
